@@ -2,7 +2,7 @@ GrantBonus <-
 bonus <-
 paybonus <-
 function(workers, assignments, amounts, reasons,
-         verbose = getOption('MTurkR.verbose'), ...) {
+         verbose = getOption('MTurkR.verbose', TRUE), ...) {
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
