@@ -1,7 +1,7 @@
 RevokeQualification <-
 RevokeQualifications <-
 revokequal <-
-function (qual, worker, reason = NULL, verbose = getOption('MTurkR.verbose'), ...){
+function (qual, worker, reason = NULL, verbose = getOption('MTurkR.verbose', TRUE), ...){
     # temporary check for `print` argument (remove after v1.0)
     if('print' %in% names(list(...)) && is.null(verbose))
         verbose <- list(...)$print
@@ -21,37 +21,37 @@ function (qual, worker, reason = NULL, verbose = getOption('MTurkR.verbose'), ..
         request <- request(operation, GETparameters = GETparameters, ...)
         if(is.null(request$valid))
             return(request)
-        if (request$valid & verbose) {
-            message(i, ": Qualification (", qualbatch, ") for worker ", 
-                workerbatch, " Revoked")
-        }
-        else if(!request$valid & verbose)
-                warning(i, ": Invalid Request for worker ", workerbatch)
         return(request)
     }
     Qualifications <- setNames(data.frame(matrix(ncol=4)),
                         c("WorkerId", "QualificationTypeId", "Reason", "Valid"))
     if(length(qual) == 1 & length(worker) == 1) {
         x <- batch(qual[1], worker[1], reason)
-        Qualifications[1, ] = c(worker[1], qual[1], reason, x$valid)
+        Qualifications[1, ] <- c(worker[1], qual[1], if(!is.null(reason)) reason else "", x$valid)
     }
     else if(length(qual) > 1 & length(worker) == 1) {
         for(i in 1:length(qual)) {
             x <- batch(qual[i], worker[1], reason)
-            Qualifications[i, ] = c(worker[1], qual[i], reason, x$valid)
+            if(x$valid & verbose) {
+                message(i, ": Qualification (", qual[i], ") for worker ", 
+                        worker[1], " Revoked")
+            }
+            else if(!x$valid & verbose)
+                warning(i, ": Invalid Request for worker ", worker[1])
+            Qualifications[i, ] <- c(worker[1], qual[i], if(!is.null(reason)) reason else "", x$valid)
         }
     }
     else if(length(qual) == 1 & length(worker) > 1) {
         for(i in 1:length(worker)) {
             x <- batch(qual[1], worker[i], reason)
-            Qualifications[i, ] = c(worker[i], qual[1], reason, x$valid)
+            Qualifications[i, ] <- c(worker[i], qual[1], if(!is.null(reason)) reason else "", x$valid)
         }
     }
     else if(length(qual) > 1 & length(worker) > 1) {
         for(i in 1:length(worker)) {
             for(j in 1:length(qual)) {
                 x <- batch(qual[j], worker[i], reason)
-                Qualifications[i, ] = c(worker[i], qual[j], reason, x$valid)
+                Qualifications[i, ] <- c(worker[i], qual[j], if(!is.null(reason)) reason else "", x$valid)
             }
         }
     }
